# openapi-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import openapi_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import openapi_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import openapi_client
from openapi_client.rest import ApiException
from pprint import pprint


# Defining host is optional and default to http://localhost
configuration.host = "http://localhost"
# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.DefaultApi(api_client)
    identity_id = 'identity_id_example' # str | 
update_organization_collaborator = openapi_client.UpdateOrganizationCollaborator() # UpdateOrganizationCollaborator | 

    try:
        # Alter Organization Collaborator
        api_response = api_instance.alter_organization_collaborator_api_v2_organization_collaborators_identity_id_put(identity_id, update_organization_collaborator)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->alter_organization_collaborator_api_v2_organization_collaborators_identity_id_put: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**alter_organization_collaborator_api_v2_organization_collaborators_identity_id_put**](docs/DefaultApi.md#alter_organization_collaborator_api_v2_organization_collaborators_identity_id_put) | **PUT** /api/v2/organization_collaborators/{identity_id} | Alter Organization Collaborator
*DefaultApi* | [**alter_project_collaborator_api_v2_projects_project_id_collaborators_role_or_identity_id_put**](docs/DefaultApi.md#alter_project_collaborator_api_v2_projects_project_id_collaborators_role_or_identity_id_put) | **PUT** /api/v2/projects/{project_id}/collaborators/{role_or_identity_id} | Alter Project Collaborator
*DefaultApi* | [**apis_enable_api_v2_clouds_gcp_enable_api_project_id_api_name_get**](docs/DefaultApi.md#apis_enable_api_v2_clouds_gcp_enable_api_project_id_api_name_get) | **GET** /api/v2/clouds/gcp/enable/api/{project_id}/{api_name} | Apis Enable
*DefaultApi* | [**change_password_api_v2_users_change_password_post**](docs/DefaultApi.md#change_password_api_v2_users_change_password_post) | **POST** /api/v2/users/change_password | Change Password
*DefaultApi* | [**check_availability_api_v2_organizations_check_availability_get**](docs/DefaultApi.md#check_availability_api_v2_organizations_check_availability_get) | **GET** /api/v2/organizations/check_availability | Check Availability
*DefaultApi* | [**check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get**](docs/DefaultApi.md#check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get) | **GET** /api/v2/userinfo/check_is_feature_flag_on | Check Is Feature Flag On
*DefaultApi* | [**create_anyscale_service_account_api_v2_clouds_gcp_create_anyscale_service_account_target_project_id_get**](docs/DefaultApi.md#create_anyscale_service_account_api_v2_clouds_gcp_create_anyscale_service_account_target_project_id_get) | **GET** /api/v2/clouds/gcp/create/anyscale_service_account/{target_project_id} | Create Anyscale Service Account
*DefaultApi* | [**create_autoscaler_service_account_api_v2_clouds_gcp_create_autoscaler_service_account_project_id_get**](docs/DefaultApi.md#create_autoscaler_service_account_api_v2_clouds_gcp_create_autoscaler_service_account_project_id_get) | **GET** /api/v2/clouds/gcp/create/autoscaler_service_account/{project_id} | Create Autoscaler Service Account
*DefaultApi* | [**create_cloud_api_v2_clouds_post**](docs/DefaultApi.md#create_cloud_api_v2_clouds_post) | **POST** /api/v2/clouds/ | Create Cloud
*DefaultApi* | [**create_from_github_api_v2_projects_create_from_github_post**](docs/DefaultApi.md#create_from_github_api_v2_projects_create_from_github_post) | **POST** /api/v2/projects/create_from_github | Create From Github
*DefaultApi* | [**create_invitation_api_v2_organization_invitations_post**](docs/DefaultApi.md#create_invitation_api_v2_organization_invitations_post) | **POST** /api/v2/organization_invitations/ | Create Invitation
*DefaultApi* | [**create_new_session_api_v2_sessions_create_from_snapshot_post**](docs/DefaultApi.md#create_new_session_api_v2_sessions_create_from_snapshot_post) | **POST** /api/v2/sessions/create_from_snapshot | Create New Session
*DefaultApi* | [**create_new_session_api_v2_sessions_create_new_session_post**](docs/DefaultApi.md#create_new_session_api_v2_sessions_create_new_session_post) | **POST** /api/v2/sessions/create_new_session | Create New Session
*DefaultApi* | [**create_project_api_v2_projects_post**](docs/DefaultApi.md#create_project_api_v2_projects_post) | **POST** /api/v2/projects/ | Create Project
*DefaultApi* | [**create_project_collaborator_api_v2_projects_project_id_collaborators_post**](docs/DefaultApi.md#create_project_collaborator_api_v2_projects_project_id_collaborators_post) | **POST** /api/v2/projects/{project_id}/collaborators | Create Project Collaborator
*DefaultApi* | [**create_snapshot_api_v2_snapshots_post**](docs/DefaultApi.md#create_snapshot_api_v2_snapshots_post) | **POST** /api/v2/snapshots/ | Create Snapshot
*DefaultApi* | [**delete_cloud_api_v2_clouds_cloud_id_delete**](docs/DefaultApi.md#delete_cloud_api_v2_clouds_cloud_id_delete) | **DELETE** /api/v2/clouds/{cloud_id} | Delete Cloud
*DefaultApi* | [**delete_project_api_v2_projects_project_id_delete**](docs/DefaultApi.md#delete_project_api_v2_projects_project_id_delete) | **DELETE** /api/v2/projects/{project_id} | Delete Project
*DefaultApi* | [**delete_project_collaborator_api_v2_projects_project_id_collaborators_role_or_identity_id_delete**](docs/DefaultApi.md#delete_project_collaborator_api_v2_projects_project_id_collaborators_role_or_identity_id_delete) | **DELETE** /api/v2/projects/{project_id}/collaborators/{role_or_identity_id} | Delete Project Collaborator
*DefaultApi* | [**delete_session_api_v2_sessions_session_id_delete**](docs/DefaultApi.md#delete_session_api_v2_sessions_session_id_delete) | **DELETE** /api/v2/sessions/{session_id} | Delete Session
*DefaultApi* | [**delete_snapshot_api_v2_snapshots_snapshot_id_delete**](docs/DefaultApi.md#delete_snapshot_api_v2_snapshots_snapshot_id_delete) | **DELETE** /api/v2/snapshots/{snapshot_id} | Delete Snapshot
*DefaultApi* | [**deregister_autosync_session_api_v2_autosync_sessions_autosync_session_id_delete**](docs/DefaultApi.md#deregister_autosync_session_api_v2_autosync_sessions_autosync_session_id_delete) | **DELETE** /api/v2/autosync_sessions/{autosync_session_id} | Deregister Autosync Session
*DefaultApi* | [**describe_session_api_v2_sessions_session_id_describe_get**](docs/DefaultApi.md#describe_session_api_v2_sessions_session_id_describe_get) | **GET** /api/v2/sessions/{session_id}/describe | Describe Session
*DefaultApi* | [**execute_command_api_v2_sessions_session_id_execute_command_name_post**](docs/DefaultApi.md#execute_command_api_v2_sessions_session_id_execute_command_name_post) | **POST** /api/v2/sessions/{session_id}/execute/{command_name} | Execute Command
*DefaultApi* | [**execute_interactive_command_api_v2_sessions_session_id_execute_interactive_command_post**](docs/DefaultApi.md#execute_interactive_command_api_v2_sessions_session_id_execute_interactive_command_post) | **POST** /api/v2/sessions/{session_id}/execute_interactive_command | Execute Interactive Command
*DefaultApi* | [**execute_shell_command_api_v2_sessions_session_id_execute_shell_command_post**](docs/DefaultApi.md#execute_shell_command_api_v2_sessions_session_id_execute_shell_command_post) | **POST** /api/v2/sessions/{session_id}/execute_shell_command | Execute Shell Command
*DefaultApi* | [**find_cloud_by_name_api_v2_clouds_find_by_name_post**](docs/DefaultApi.md#find_cloud_by_name_api_v2_clouds_find_by_name_post) | **POST** /api/v2/clouds/find_by_name | Find Cloud By Name
*DefaultApi* | [**find_project_by_project_name_api_v2_projects_find_by_name_get**](docs/DefaultApi.md#find_project_by_project_name_api_v2_projects_find_by_name_get) | **GET** /api/v2/projects/find_by_name | Find Project By Project Name
*DefaultApi* | [**find_with_invitation_api_v2_organizations_find_with_invitation_get**](docs/DefaultApi.md#find_with_invitation_api_v2_organizations_find_with_invitation_get) | **GET** /api/v2/organizations/find_with_invitation | Find With Invitation
*DefaultApi* | [**find_with_public_identifier_api_v2_organizations_find_with_public_identifier_get**](docs/DefaultApi.md#find_with_public_identifier_api_v2_organizations_find_with_public_identifier_get) | **GET** /api/v2/organizations/find_with_public_identifier | Find With Public Identifier
*DefaultApi* | [**finish_session_command_api_v2_session_commands_session_command_id_finish_post**](docs/DefaultApi.md#finish_session_command_api_v2_session_commands_session_command_id_finish_post) | **POST** /api/v2/session_commands/{session_command_id}/finish | Finish Session Command
*DefaultApi* | [**fork_session_api_v2_sessions_session_id_fork_post**](docs/DefaultApi.md#fork_session_api_v2_sessions_session_id_fork_post) | **POST** /api/v2/sessions/{session_id}/fork | Fork Session
*DefaultApi* | [**gcp_create_cloud_api_v2_clouds_gcp_create_cloud_name_get**](docs/DefaultApi.md#gcp_create_cloud_api_v2_clouds_gcp_create_cloud_name_get) | **GET** /api/v2/clouds/gcp/create/{cloud_name} | Gcp Create Cloud
*DefaultApi* | [**gcp_create_project_api_v2_clouds_gcp_create_project_get**](docs/DefaultApi.md#gcp_create_project_api_v2_clouds_gcp_create_project_get) | **GET** /api/v2/clouds/gcp/create/project | Gcp Create Project
*DefaultApi* | [**get_active_autosync_sessions_for_session_api_v2_autosync_sessions_get**](docs/DefaultApi.md#get_active_autosync_sessions_for_session_api_v2_autosync_sessions_get) | **GET** /api/v2/autosync_sessions/ | Get Active Autosync Sessions For Session
*DefaultApi* | [**get_anyscale_aws_account_api_v2_clouds_anyscale_aws_account_get**](docs/DefaultApi.md#get_anyscale_aws_account_api_v2_clouds_anyscale_aws_account_get) | **GET** /api/v2/clouds/anyscale/aws_account | Get Anyscale Aws Account
*DefaultApi* | [**get_anyscale_version_api_v2_userinfo_anyscale_version_get**](docs/DefaultApi.md#get_anyscale_version_api_v2_userinfo_anyscale_version_get) | **GET** /api/v2/userinfo/anyscale_version | Get Anyscale Version
*DefaultApi* | [**get_cloud_api_v2_clouds_cloud_id_get**](docs/DefaultApi.md#get_cloud_api_v2_clouds_cloud_id_get) | **GET** /api/v2/clouds/{cloud_id} | Get Cloud
*DefaultApi* | [**get_execution_logs_api_v2_session_commands_session_command_id_execution_logs_get**](docs/DefaultApi.md#get_execution_logs_api_v2_session_commands_session_command_id_execution_logs_get) | **GET** /api/v2/session_commands/{session_command_id}/execution_logs | Get Execution Logs
*DefaultApi* | [**get_execution_logs_archived_api_v2_session_commands_session_command_id_execution_logs_archived_get**](docs/DefaultApi.md#get_execution_logs_archived_api_v2_session_commands_session_command_id_execution_logs_archived_get) | **GET** /api/v2/session_commands/{session_command_id}/execution_logs_archived | Get Execution Logs Archived
*DefaultApi* | [**get_invitation_api_v2_organization_invitations_invitation_id_get**](docs/DefaultApi.md#get_invitation_api_v2_organization_invitations_invitation_id_get) | **GET** /api/v2/organization_invitations/{invitation_id} | Get Invitation
*DefaultApi* | [**get_monitor_logs_api_v2_sessions_session_id_monitor_logs_get**](docs/DefaultApi.md#get_monitor_logs_api_v2_sessions_session_id_monitor_logs_get) | **GET** /api/v2/sessions/{session_id}/monitor_logs | Get Monitor Logs
*DefaultApi* | [**get_monitor_logs_archived_api_v2_sessions_session_id_monitor_logs_archived_get**](docs/DefaultApi.md#get_monitor_logs_archived_api_v2_sessions_session_id_monitor_logs_archived_get) | **GET** /api/v2/sessions/{session_id}/monitor_logs_archived | Get Monitor Logs Archived
*DefaultApi* | [**get_project_api_v2_projects_project_id_get**](docs/DefaultApi.md#get_project_api_v2_projects_project_id_get) | **GET** /api/v2/projects/{project_id} | Get Project
*DefaultApi* | [**get_project_default_session_name_api_v2_projects_project_id_default_session_name_get**](docs/DefaultApi.md#get_project_default_session_name_api_v2_projects_project_id_default_session_name_get) | **GET** /api/v2/projects/{project_id}/default_session_name | Get Project Default Session Name
*DefaultApi* | [**get_project_latest_cluster_config_api_v2_projects_project_id_latest_cluster_config_get**](docs/DefaultApi.md#get_project_latest_cluster_config_api_v2_projects_project_id_latest_cluster_config_get) | **GET** /api/v2/projects/{project_id}/latest_cluster_config | Get Project Latest Cluster Config
*DefaultApi* | [**get_session_api_v2_sessions_session_id_get**](docs/DefaultApi.md#get_session_api_v2_sessions_session_id_get) | **GET** /api/v2/sessions/{session_id} | Get Session
*DefaultApi* | [**get_session_autoscaler_credentials_api_v2_sessions_session_id_autoscaler_credentials_get**](docs/DefaultApi.md#get_session_autoscaler_credentials_api_v2_sessions_session_id_autoscaler_credentials_get) | **GET** /api/v2/sessions/{session_id}/autoscaler_credentials | Get Session Autoscaler Credentials
*DefaultApi* | [**get_session_cluster_config_api_v2_sessions_session_id_cluster_config_get**](docs/DefaultApi.md#get_session_cluster_config_api_v2_sessions_session_id_cluster_config_get) | **GET** /api/v2/sessions/{session_id}/cluster_config | Get Session Cluster Config
*DefaultApi* | [**get_session_commands_history_api_v2_session_commands_get**](docs/DefaultApi.md#get_session_commands_history_api_v2_session_commands_get) | **GET** /api/v2/session_commands/ | Get Session Commands History
*DefaultApi* | [**get_session_details_api_v2_sessions_session_id_details_get**](docs/DefaultApi.md#get_session_details_api_v2_sessions_session_id_details_get) | **GET** /api/v2/sessions/{session_id}/details | Get Session Details
*DefaultApi* | [**get_session_head_ip_api_v2_sessions_session_id_head_ip_get**](docs/DefaultApi.md#get_session_head_ip_api_v2_sessions_session_id_head_ip_get) | **GET** /api/v2/sessions/{session_id}/head_ip | Get Session Head Ip
*DefaultApi* | [**get_session_history_api_v2_sessions_session_id_history_get**](docs/DefaultApi.md#get_session_history_api_v2_sessions_session_id_history_get) | **GET** /api/v2/sessions/{session_id}/history | Get Session History
*DefaultApi* | [**get_session_overview_api_v2_overview_get**](docs/DefaultApi.md#get_session_overview_api_v2_overview_get) | **GET** /api/v2/overview | Get Session Overview
*DefaultApi* | [**get_session_ssh_key_api_v2_sessions_session_id_ssh_key_get**](docs/DefaultApi.md#get_session_ssh_key_api_v2_sessions_session_id_ssh_key_get) | **GET** /api/v2/sessions/{session_id}/ssh_key | Get Session Ssh Key
*DefaultApi* | [**get_snapshot_api_v2_snapshots_snapshot_id_get**](docs/DefaultApi.md#get_snapshot_api_v2_snapshots_snapshot_id_get) | **GET** /api/v2/snapshots/{snapshot_id} | Get Snapshot
*DefaultApi* | [**get_snapshot_cluster_config_api_v2_snapshots_snapshot_id_cluster_config_get**](docs/DefaultApi.md#get_snapshot_cluster_config_api_v2_snapshots_snapshot_id_cluster_config_get) | **GET** /api/v2/snapshots/{snapshot_id}/cluster_config | Get Snapshot Cluster Config
*DefaultApi* | [**get_snapshot_files_api_v2_snapshots_snapshot_id_files_get**](docs/DefaultApi.md#get_snapshot_files_api_v2_snapshots_snapshot_id_files_get) | **GET** /api/v2/snapshots/{snapshot_id}/files | Get Snapshot Files
*DefaultApi* | [**get_startup_logs_api_v2_sessions_session_id_startup_logs_get**](docs/DefaultApi.md#get_startup_logs_api_v2_sessions_session_id_startup_logs_get) | **GET** /api/v2/sessions/{session_id}/startup_logs | Get Startup Logs
*DefaultApi* | [**get_startup_logs_archived_api_v2_sessions_session_id_startup_logs_archived_get**](docs/DefaultApi.md#get_startup_logs_archived_api_v2_sessions_session_id_startup_logs_archived_get) | **GET** /api/v2/sessions/{session_id}/startup_logs_archived | Get Startup Logs Archived
*DefaultApi* | [**get_user_info_api_v2_userinfo_get**](docs/DefaultApi.md#get_user_info_api_v2_userinfo_get) | **GET** /api/v2/userinfo/ | Get User Info
*DefaultApi* | [**google_auth_api_v2_oauth2_google_auth_cloud_name_get**](docs/DefaultApi.md#google_auth_api_v2_oauth2_google_auth_cloud_name_get) | **GET** /api/v2/oauth2/google/auth/{cloud_name} | Google Auth
*DefaultApi* | [**google_callback_api_v2_oauth2_google_callback_get**](docs/DefaultApi.md#google_callback_api_v2_oauth2_google_callback_get) | **GET** /api/v2/oauth2/google/callback | Google Callback
*DefaultApi* | [**handle_gateway_interaction_api_v2_cloudgateway_gateway_id_post**](docs/DefaultApi.md#handle_gateway_interaction_api_v2_cloudgateway_gateway_id_post) | **POST** /api/v2/cloudgateway/{gateway_id} | Handle Gateway Interaction
*DefaultApi* | [**heartbeat_api_v2_autosync_sessions_autosync_session_id_heartbeat_post**](docs/DefaultApi.md#heartbeat_api_v2_autosync_sessions_autosync_session_id_heartbeat_post) | **POST** /api/v2/autosync_sessions/{autosync_session_id}/heartbeat | Heartbeat
*DefaultApi* | [**iam_create_api_v2_clouds_gcp_create_iam_project_id_get**](docs/DefaultApi.md#iam_create_api_v2_clouds_gcp_create_iam_project_id_get) | **GET** /api/v2/clouds/gcp/create/iam/{project_id} | Iam Create
*DefaultApi* | [**invalidate_invitation_api_v2_organization_invitations_invitation_id_invalidate_post**](docs/DefaultApi.md#invalidate_invitation_api_v2_organization_invitations_invitation_id_invalidate_post) | **POST** /api/v2/organization_invitations/{invitation_id}/invalidate | Invalidate Invitation
*DefaultApi* | [**kill_session_command_api_v2_session_commands_session_command_id_kill_post**](docs/DefaultApi.md#kill_session_command_api_v2_session_commands_session_command_id_kill_post) | **POST** /api/v2/session_commands/{session_command_id}/kill | Kill Session Command
*DefaultApi* | [**list_clouds_api_v2_clouds_get**](docs/DefaultApi.md#list_clouds_api_v2_clouds_get) | **GET** /api/v2/clouds/ | List Clouds
*DefaultApi* | [**list_organization_collaborators_api_v2_organization_collaborators_get**](docs/DefaultApi.md#list_organization_collaborators_api_v2_organization_collaborators_get) | **GET** /api/v2/organization_collaborators/ | List Organization Collaborators
*DefaultApi* | [**list_project_collaborators_api_v2_projects_project_id_collaborators_get**](docs/DefaultApi.md#list_project_collaborators_api_v2_projects_project_id_collaborators_get) | **GET** /api/v2/projects/{project_id}/collaborators | List Project Collaborators
*DefaultApi* | [**list_projects_api_v2_projects_get**](docs/DefaultApi.md#list_projects_api_v2_projects_get) | **GET** /api/v2/projects/ | List Projects
*DefaultApi* | [**list_sessions_api_v2_sessions_get**](docs/DefaultApi.md#list_sessions_api_v2_sessions_get) | **GET** /api/v2/sessions/ | List Sessions
*DefaultApi* | [**list_snapshots_api_v2_snapshots_get**](docs/DefaultApi.md#list_snapshots_api_v2_snapshots_get) | **GET** /api/v2/snapshots/ | List Snapshots
*DefaultApi* | [**login_user_api_v2_users_login_post**](docs/DefaultApi.md#login_user_api_v2_users_login_post) | **POST** /api/v2/users/login | Login User
*DefaultApi* | [**logout_user_api_v2_users_logout_post**](docs/DefaultApi.md#logout_user_api_v2_users_logout_post) | **POST** /api/v2/users/logout | Logout User
*DefaultApi* | [**patch_project_api_v2_projects_project_id_patch**](docs/DefaultApi.md#patch_project_api_v2_projects_project_id_patch) | **PATCH** /api/v2/projects/{project_id} | Patch Project
*DefaultApi* | [**patch_session_api_v2_sessions_session_id_patch**](docs/DefaultApi.md#patch_session_api_v2_sessions_session_id_patch) | **PATCH** /api/v2/sessions/{session_id} | Patch Session
*DefaultApi* | [**patch_snapshot_api_v2_snapshots_snapshot_id_patch**](docs/DefaultApi.md#patch_snapshot_api_v2_snapshots_snapshot_id_patch) | **PATCH** /api/v2/snapshots/{snapshot_id} | Patch Snapshot
*DefaultApi* | [**put_session_cluster_config_api_v2_sessions_session_id_cluster_config_put**](docs/DefaultApi.md#put_session_cluster_config_api_v2_sessions_session_id_cluster_config_put) | **PUT** /api/v2/sessions/{session_id}/cluster_config | Put Session Cluster Config
*DefaultApi* | [**put_snapshot_cluster_config_api_v2_snapshots_snapshot_id_cluster_config_put**](docs/DefaultApi.md#put_snapshot_cluster_config_api_v2_snapshots_snapshot_id_cluster_config_put) | **PUT** /api/v2/snapshots/{snapshot_id}/cluster_config | Put Snapshot Cluster Config
*DefaultApi* | [**register_autosync_session_api_v2_autosync_sessions_post**](docs/DefaultApi.md#register_autosync_session_api_v2_autosync_sessions_post) | **POST** /api/v2/autosync_sessions/ | Register Autosync Session
*DefaultApi* | [**register_user_api_v2_users_post**](docs/DefaultApi.md#register_user_api_v2_users_post) | **POST** /api/v2/users/ | Register User
*DefaultApi* | [**remove_organization_collaborator_api_v2_organization_collaborators_identity_id_delete**](docs/DefaultApi.md#remove_organization_collaborator_api_v2_organization_collaborators_identity_id_delete) | **DELETE** /api/v2/organization_collaborators/{identity_id} | Remove Organization Collaborator
*DefaultApi* | [**request_organization_identifiers_api_v2_users_request_organization_identifiers_post**](docs/DefaultApi.md#request_organization_identifiers_api_v2_users_request_organization_identifiers_post) | **POST** /api/v2/users/request_organization_identifiers | Request Organization Identifiers
*DefaultApi* | [**request_password_reset_api_v2_users_request_password_reset_post**](docs/DefaultApi.md#request_password_reset_api_v2_users_request_password_reset_post) | **POST** /api/v2/users/request_password_reset | Request Password Reset
*DefaultApi* | [**rerun_command_api_v2_session_commands_session_command_id_rerun_post**](docs/DefaultApi.md#rerun_command_api_v2_session_commands_session_command_id_rerun_post) | **POST** /api/v2/session_commands/{session_command_id}/rerun | Rerun Command
*DefaultApi* | [**reset_password_api_v2_users_reset_password_post**](docs/DefaultApi.md#reset_password_api_v2_users_reset_password_post) | **POST** /api/v2/users/reset_password | Reset Password
*DefaultApi* | [**session_finish_up_api_v2_sessions_session_id_finish_up_post**](docs/DefaultApi.md#session_finish_up_api_v2_sessions_session_id_finish_up_post) | **POST** /api/v2/sessions/{session_id}/finish_up | Session Finish Up
*DefaultApi* | [**session_get_anyscale_wheel_api_v2_sessions_session_id_anyscale_wheel_get**](docs/DefaultApi.md#session_get_anyscale_wheel_api_v2_sessions_session_id_anyscale_wheel_get) | **GET** /api/v2/sessions/{session_id}/anyscale_wheel | Session Get Anyscale Wheel
*DefaultApi* | [**session_report_command_api_v2_session_commands_session_command_id_report_command_post**](docs/DefaultApi.md#session_report_command_api_v2_session_commands_session_command_id_report_command_post) | **POST** /api/v2/session_commands/{session_command_id}/report_command | Session Report Command
*DefaultApi* | [**session_up_api_v2_sessions_up_post**](docs/DefaultApi.md#session_up_api_v2_sessions_up_post) | **POST** /api/v2/sessions/up | Session Up
*DefaultApi* | [**set_ray_dashboard_url_api_v2_sessions_session_id_ray_dashboard_url_post**](docs/DefaultApi.md#set_ray_dashboard_url_api_v2_sessions_session_id_ray_dashboard_url_post) | **POST** /api/v2/sessions/{session_id}/ray_dashboard_url | Set Ray Dashboard Url
*DefaultApi* | [**setup_billing_api_v2_clouds_gcp_setup_billing_project_id_get**](docs/DefaultApi.md#setup_billing_api_v2_clouds_gcp_setup_billing_project_id_get) | **GET** /api/v2/clouds/gcp/setup_billing/{project_id} | Setup Billing
*DefaultApi* | [**start_session_api_v2_sessions_session_id_start_post**](docs/DefaultApi.md#start_session_api_v2_sessions_session_id_start_post) | **POST** /api/v2/sessions/{session_id}/start | Start Session
*DefaultApi* | [**stop_session_api_v2_sessions_session_id_stop_post**](docs/DefaultApi.md#stop_session_api_v2_sessions_session_id_stop_post) | **POST** /api/v2/sessions/{session_id}/stop | Stop Session
*DefaultApi* | [**take_snapshot_api_v2_sessions_session_id_take_snapshot_post**](docs/DefaultApi.md#take_snapshot_api_v2_sessions_session_id_take_snapshot_post) | **POST** /api/v2/sessions/{session_id}/take_snapshot | Take Snapshot
*DefaultApi* | [**upload_session_command_logs_api_v2_session_commands_session_command_id_upload_logs_post**](docs/DefaultApi.md#upload_session_command_logs_api_v2_session_commands_session_command_id_upload_logs_post) | **POST** /api/v2/session_commands/{session_command_id}/upload_logs | Upload Session Command Logs
*DefaultApi* | [**user_get_temporary_aws_credentials_api_v2_users_temporary_aws_credentials_get**](docs/DefaultApi.md#user_get_temporary_aws_credentials_api_v2_users_temporary_aws_credentials_get) | **GET** /api/v2/users/temporary_aws_credentials | User Get Temporary Aws Credentials
*DefaultApi* | [**user_resend_email_api_v2_users_resend_email_post**](docs/DefaultApi.md#user_resend_email_api_v2_users_resend_email_post) | **POST** /api/v2/users/resend_email | User Resend Email
*DefaultApi* | [**user_server_session_token_api_v2_users_server_session_token_post**](docs/DefaultApi.md#user_server_session_token_api_v2_users_server_session_token_post) | **POST** /api/v2/users/server_session_token | User Server Session Token
*DefaultApi* | [**user_verify_api_v2_users_verify_token_get**](docs/DefaultApi.md#user_verify_api_v2_users_verify_token_get) | **GET** /api/v2/users/verify/{token} | User Verify
*DefaultApi* | [**validate_cluster_api_v2_sessions_validate_cluster_post**](docs/DefaultApi.md#validate_cluster_api_v2_sessions_validate_cluster_post) | **POST** /api/v2/sessions/validate_cluster | Validate Cluster
*DefaultApi* | [**verify_reset_password_token_api_v2_users_reset_password_token_get**](docs/DefaultApi.md#verify_reset_password_token_api_v2_users_reset_password_token_get) | **GET** /api/v2/users/reset_password/{token} | Verify Reset Password Token


## Documentation For Models

 - [AWSCredentials](docs/AWSCredentials.md)
 - [AnyscaleAWSAccount](docs/AnyscaleAWSAccount.md)
 - [AnyscaleVersionResponse](docs/AnyscaleVersionResponse.md)
 - [AnyscaleawsaccountResponse](docs/AnyscaleawsaccountResponse.md)
 - [AnyscaleversionresponseResponse](docs/AnyscaleversionresponseResponse.md)
 - [AppliedSnapshot](docs/AppliedSnapshot.md)
 - [ArchivedLogsInfo](docs/ArchivedLogsInfo.md)
 - [ArchivedlogsinfoResponse](docs/ArchivedlogsinfoResponse.md)
 - [AutoscalerCredentials](docs/AutoscalerCredentials.md)
 - [AutoscalercredentialsResponse](docs/AutoscalercredentialsResponse.md)
 - [AutosyncSessionId](docs/AutosyncSessionId.md)
 - [AutosyncsessionidListResponse](docs/AutosyncsessionidListResponse.md)
 - [AutosyncsessionidResponse](docs/AutosyncsessionidResponse.md)
 - [AwscredentialsResponse](docs/AwscredentialsResponse.md)
 - [ChangePasswordParams](docs/ChangePasswordParams.md)
 - [Cloud](docs/Cloud.md)
 - [CloudListResponse](docs/CloudListResponse.md)
 - [CloudNameOptions](docs/CloudNameOptions.md)
 - [CloudProviders](docs/CloudProviders.md)
 - [CloudResponse](docs/CloudResponse.md)
 - [CloudTypes](docs/CloudTypes.md)
 - [ClusterConfig](docs/ClusterConfig.md)
 - [ClusterconfigResponse](docs/ClusterconfigResponse.md)
 - [CreateFromGithubOptions](docs/CreateFromGithubOptions.md)
 - [CreateOrganizationInvitation](docs/CreateOrganizationInvitation.md)
 - [CreateSessionFromSnapshotOptions](docs/CreateSessionFromSnapshotOptions.md)
 - [CreateSnapshotOptions](docs/CreateSnapshotOptions.md)
 - [CreateUser](docs/CreateUser.md)
 - [ExecuteCommandOptions](docs/ExecuteCommandOptions.md)
 - [ExecuteCommandResponse](docs/ExecuteCommandResponse.md)
 - [ExecuteShellCommandOptions](docs/ExecuteShellCommandOptions.md)
 - [ExecutecommandresponseResponse](docs/ExecutecommandresponseResponse.md)
 - [FeatureFlagResponse](docs/FeatureFlagResponse.md)
 - [FeatureflagresponseResponse](docs/FeatureflagresponseResponse.md)
 - [GatewayRequest](docs/GatewayRequest.md)
 - [GatewayrequestResponse](docs/GatewayrequestResponse.md)
 - [GithubProject](docs/GithubProject.md)
 - [GithubprojectResponse](docs/GithubprojectResponse.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [HeadIp](docs/HeadIp.md)
 - [HeadipResponse](docs/HeadipResponse.md)
 - [JsonDumpedGatewayResponseMessage](docs/JsonDumpedGatewayResponseMessage.md)
 - [JsonPatchOperation](docs/JsonPatchOperation.md)
 - [ListResponseMetadata](docs/ListResponseMetadata.md)
 - [LoginUserParams](docs/LoginUserParams.md)
 - [LogsOutput](docs/LogsOutput.md)
 - [LogsoutputResponse](docs/LogsoutputResponse.md)
 - [Organization](docs/Organization.md)
 - [OrganizationAvailability](docs/OrganizationAvailability.md)
 - [OrganizationInvitation](docs/OrganizationInvitation.md)
 - [OrganizationInvitationBase](docs/OrganizationInvitationBase.md)
 - [OrganizationPermissionLevel](docs/OrganizationPermissionLevel.md)
 - [OrganizationResponse](docs/OrganizationResponse.md)
 - [OrganizationavailabilityResponse](docs/OrganizationavailabilityResponse.md)
 - [OrganizationinvitationResponse](docs/OrganizationinvitationResponse.md)
 - [OrganizationinvitationbaseResponse](docs/OrganizationinvitationbaseResponse.md)
 - [PermissionLevel](docs/PermissionLevel.md)
 - [Project](docs/Project.md)
 - [ProjectBase](docs/ProjectBase.md)
 - [ProjectCollaborator](docs/ProjectCollaborator.md)
 - [ProjectCollaboratorValue](docs/ProjectCollaboratorValue.md)
 - [ProjectDefaultSessionName](docs/ProjectDefaultSessionName.md)
 - [ProjectListResponse](docs/ProjectListResponse.md)
 - [ProjectResponse](docs/ProjectResponse.md)
 - [ProjectbaseResponse](docs/ProjectbaseResponse.md)
 - [ProjectcollaboratorListResponse](docs/ProjectcollaboratorListResponse.md)
 - [ProjectdefaultsessionnameResponse](docs/ProjectdefaultsessionnameResponse.md)
 - [RequestOrganizationIdentifiersParams](docs/RequestOrganizationIdentifiersParams.md)
 - [RequestPasswordResetParams](docs/RequestPasswordResetParams.md)
 - [ResetPasswordParams](docs/ResetPasswordParams.md)
 - [S3DownloadLocation](docs/S3DownloadLocation.md)
 - [ServerSessionToken](docs/ServerSessionToken.md)
 - [ServersessiontokenResponse](docs/ServersessiontokenResponse.md)
 - [Session](docs/Session.md)
 - [SessionCommand](docs/SessionCommand.md)
 - [SessionCommandFinishOptions](docs/SessionCommandFinishOptions.md)
 - [SessionCommandId](docs/SessionCommandId.md)
 - [SessionDescribe](docs/SessionDescribe.md)
 - [SessionDetails](docs/SessionDetails.md)
 - [SessionFinishUpOptions](docs/SessionFinishUpOptions.md)
 - [SessionHistoryItem](docs/SessionHistoryItem.md)
 - [SessionId](docs/SessionId.md)
 - [SessionListResponse](docs/SessionListResponse.md)
 - [SessionOverview](docs/SessionOverview.md)
 - [SessionReportCommandOptions](docs/SessionReportCommandOptions.md)
 - [SessionResponse](docs/SessionResponse.md)
 - [SessionSshKey](docs/SessionSshKey.md)
 - [SessionStartingUpData](docs/SessionStartingUpData.md)
 - [SessionState](docs/SessionState.md)
 - [SessionStateData](docs/SessionStateData.md)
 - [SessionStoppingData](docs/SessionStoppingData.md)
 - [SessionUpOptions](docs/SessionUpOptions.md)
 - [SessionUpResponse](docs/SessionUpResponse.md)
 - [SessioncommandListResponse](docs/SessioncommandListResponse.md)
 - [SessioncommandidResponse](docs/SessioncommandidResponse.md)
 - [SessiondescribeResponse](docs/SessiondescribeResponse.md)
 - [SessiondetailsResponse](docs/SessiondetailsResponse.md)
 - [SessionhistoryitemListResponse](docs/SessionhistoryitemListResponse.md)
 - [SessionidResponse](docs/SessionidResponse.md)
 - [SessionoverviewListResponse](docs/SessionoverviewListResponse.md)
 - [SessionsshkeyResponse](docs/SessionsshkeyResponse.md)
 - [SessionupresponseResponse](docs/SessionupresponseResponse.md)
 - [Snapshot](docs/Snapshot.md)
 - [SnapshotCreate](docs/SnapshotCreate.md)
 - [SnapshotDelete](docs/SnapshotDelete.md)
 - [SnapshotFiles](docs/SnapshotFiles.md)
 - [SnapshotID](docs/SnapshotID.md)
 - [SnapshotList](docs/SnapshotList.md)
 - [SnapshotListItem](docs/SnapshotListItem.md)
 - [SnapshotProjectFile](docs/SnapshotProjectFile.md)
 - [SnapshotResponse](docs/SnapshotResponse.md)
 - [SnapshotcreateResponse](docs/SnapshotcreateResponse.md)
 - [SnapshotdeleteResponse](docs/SnapshotdeleteResponse.md)
 - [SnapshotfilesResponse](docs/SnapshotfilesResponse.md)
 - [SnapshotidResponse](docs/SnapshotidResponse.md)
 - [SnapshotlistResponse](docs/SnapshotlistResponse.md)
 - [StartSessionOptions](docs/StartSessionOptions.md)
 - [StopSessionOptions](docs/StopSessionOptions.md)
 - [TakeSnapshotOptions](docs/TakeSnapshotOptions.md)
 - [UpdateOrganizationCollaborator](docs/UpdateOrganizationCollaborator.md)
 - [UpdateProjectCollaborator](docs/UpdateProjectCollaborator.md)
 - [UploadSessionCommandLogsLocations](docs/UploadSessionCommandLogsLocations.md)
 - [UploadsessioncommandlogslocationsResponse](docs/UploadsessioncommandlogslocationsResponse.md)
 - [UserInfo](docs/UserInfo.md)
 - [UserResendEmailOptions](docs/UserResendEmailOptions.md)
 - [UserinfoResponse](docs/UserinfoResponse.md)
 - [ValidationError](docs/ValidationError.md)
 - [WriteCloud](docs/WriteCloud.md)
 - [WriteClusterConfig](docs/WriteClusterConfig.md)
 - [WriteProject](docs/WriteProject.md)
 - [WriteProjectCollaborator](docs/WriteProjectCollaborator.md)
 - [WriteProjectCollaboratorValue](docs/WriteProjectCollaboratorValue.md)
 - [WriteSession](docs/WriteSession.md)
 - [WriteSnapshot](docs/WriteSnapshot.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author




